package com.supervision.knowsub.controller.system;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.supervision.knowsub.service.ApplicationSubLibraryService;
import com.supervision.knowsub.vo.sublibrary.SubLibraryReqVo;
import com.supervision.knowsub.vo.sublibrary.SubLibraryResVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;


/**
 * 应用子库管理
 */
@Tag(name = "应用子库管理")
@RestController
@RequestMapping("/applicationSubLibrary")
@RequiredArgsConstructor
public class ApplicationSubLibraryController {


    private final ApplicationSubLibraryService applicationSubLibraryService;

    @Operation(summary = "增加应用子库")
    @PostMapping("/save")
    public String saveSubLibrary(@RequestBody SubLibraryReqVo subLibraryReqVo) {

        return applicationSubLibraryService.saveSubLibrary(subLibraryReqVo);
    }

    @Operation(summary = "修改应用子库")
    @PostMapping("/update")
    public void updateSubLibrary(@RequestBody SubLibraryReqVo subLibraryReqVo) {

        applicationSubLibraryService.updateSubLibrary(subLibraryReqVo);
    }

    @Operation(summary = "删除应用子库")
    @DeleteMapping("/delete")
    public Boolean deleteSubLibrary(@Parameter(name = "id") @RequestParam(name="id") String id) {

        return applicationSubLibraryService.deleteSubLibrary(id);
    }

    @Operation(summary = "分页查询应用子库")
    @GetMapping("/list")
    public IPage<SubLibraryResVo> listSubLibrary(@Parameter(name = "baseName",description = "应用子库名") @RequestParam(required = false) String baseName,
                                                 @Parameter(name = "baseCode",description = "应用库code") @RequestParam(required = false) String baseCode,
                                                 @Parameter(name = "pageNum",description = "页码") @RequestParam(defaultValue = "1") Integer pageNum,
                                                 @Parameter(name = "pageSize",description = "每页大小") @RequestParam(defaultValue = "10") Integer pageSize) {

        SubLibraryReqVo subLibraryReqVo = new SubLibraryReqVo();
        subLibraryReqVo.setBaseCode(baseCode);
        subLibraryReqVo.setBaseName(baseName);
        return applicationSubLibraryService.listSubLibrary(subLibraryReqVo,pageNum,pageSize);
    }
}
