package com.supervision.knowsub.controller.system;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.supervision.knowsub.service.DeptManageService;
import com.supervision.knowsub.vo.dept.DeptInfoReqVo;
import com.supervision.knowsub.vo.dept.DeptInfoResVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

@Tag(name = "部门管理")
@RestController
@RequestMapping("/deptManage")
@RequiredArgsConstructor
public class DeptManageController {


    private final DeptManageService deptManageService;

    @Operation(summary = "增加部门信息")
    @PostMapping("/save")
    public String saveDept(@RequestBody DeptInfoReqVo deptInfoReqVo) {

        return deptManageService.saveDept(deptInfoReqVo);
    }

    @Operation(summary = "修改部门信息")
    @PostMapping("/update")
    public void updateDept(@RequestBody DeptInfoReqVo deptInfoReqVo) {

        deptManageService.updateDept(deptInfoReqVo);
    }

    @Operation(summary = "删除部门信息")
    @DeleteMapping("/delete")
    public Boolean deleteDept(@Parameter(name = "id") @RequestParam(name="id") String id) {

        return deptManageService.deleteDept(id);
    }

    @Operation(summary = "分页查询部门信息列表")
    @GetMapping("/list")
    public IPage<DeptInfoResVo> listDept(@Parameter(name = "deptName",description = "机构名称") @RequestParam(required = false) String deptName,
                                         @Parameter(name = "deptCode",description = "机构编码") @RequestParam(required = false) String deptCode,
                                         @Parameter(name = "pageNum",description = "页码") @RequestParam(defaultValue = "1") Integer pageNum,
                                         @Parameter(name = "pageSize",description = "每页大小") @RequestParam(defaultValue = "10") Integer pageSize) {

        return deptManageService.pageListDept(deptName,deptCode,pageNum,pageSize);
    }
}
