package com.supervision.knowsub.controller.system;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.supervision.knowsub.model.SystemDic;
import com.supervision.knowsub.model.SystemDicData;
import com.supervision.knowsub.service.DicManageService;
import com.supervision.knowsub.vo.dic.DicDataReqVo;
import com.supervision.knowsub.vo.dic.DicReqVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Tag(name = "字典管理")
@RestController
@RequestMapping("/dicManage")
@RequiredArgsConstructor
public class DicManageController {


    private final DicManageService dicManageService;

    @Operation(summary = "增加字典信息")
    @PostMapping("/saveDic")
    public String saveDic(@RequestBody DicReqVo dicReqVo) {

        return dicManageService.saveDic(dicReqVo);
    }

    @Operation(summary = "修改字典信息")
    @PostMapping("/updateDic")
    public void updateDic(@RequestBody DicReqVo dicReqVo) {

        dicManageService.updateDic(dicReqVo);
    }

    @Operation(summary = "删除字典信息")
    @DeleteMapping("/delete")
    public Boolean deleteDic(@Parameter(name = "id") @RequestParam(name="id") String id) {

        return dicManageService.deleteDic(id);
    }

    @Operation(summary = "分页查询字典信息列表")
    @GetMapping("/list")
    public IPage<SystemDic> listDic(@Parameter(name = "dicName",description = "字典名称") @RequestParam(required = false) String dicName,
                                    @Parameter(name = "dicCode",description = "字典编码") @RequestParam(required = false) String dicCode,
                                    @Parameter(name = "pageNum",description = "页码") @RequestParam(defaultValue = "1") Integer pageNum,
                                    @Parameter(name = "pageSize",description = "每页大小") @RequestParam(defaultValue = "10") Integer pageSize) {

        return dicManageService.listDic(dicName,dicCode,pageNum,pageSize);
    }

    @Operation(summary = "保存字典值配置信息")
    @PostMapping("/saveDicData")
    public String saveDicData(@RequestParam(name = "dicId") String dicId, @RequestBody List<DicDataReqVo> dicDataReqVoList) {

        return dicManageService.saveDicData(dicId,dicDataReqVoList);
    }


    @Operation(summary = "查询字典配置信息列表")
    @GetMapping("/queryDicDate")
    public List<SystemDicData> queryDicDate(@RequestParam(name = "dicId") String dicId) {

        return dicManageService.queryDicDate(dicId);
    }
}
