package com.supervision.knowsub.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.lang.Assert;
import com.supervision.knowsub.dto.role.UserRoleDTO;
import com.supervision.knowsub.model.SystemUserRoleRelation;
import com.supervision.knowsub.service.SystemUserRoleRelationService;
import com.supervision.knowsub.service.UserRoleRelationManageService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

@Slf4j
@Service
@RequiredArgsConstructor
public class UserRoleRelationManageServiceImpl implements UserRoleRelationManageService {

    private final SystemUserRoleRelationService userRoleRelationService;
    @Override
    @Transactional(rollbackFor = Exception.class)
    public List<SystemUserRoleRelation> saveUserRoleRelation(String userId, List<String> roleIdList) {
        Assert.notEmpty(userId, "用户id不能为空");

        if (CollUtil.isEmpty(roleIdList)){
            log.info("saveUserRoleRelation:userId:{},roleList is empty",userId);
            return CollUtil.newArrayList();
        }
        List<SystemUserRoleRelation> userRoleList = roleIdList.stream().map(roleId -> {
            SystemUserRoleRelation userRole = new SystemUserRoleRelation();
            userRole.setRoleId(roleId);
            userRole.setUserId(userId);
            return userRole;
        }).toList();
        userRoleRelationService.saveBatch(userRoleList);
        return userRoleList;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public List<SystemUserRoleRelation> updateUserRoleRelation(String userId, List<String> roleIdList) {
        Assert.notEmpty(userId, "用户id不能为空");

        userRoleRelationService.lambdaUpdate().eq(SystemUserRoleRelation::getUserId,userId).remove();

        if (CollUtil.isEmpty(roleIdList)){
            log.info("updateUserRoleRelation:userId:{},roleList is empty",userId);
            return CollUtil.newArrayList();
        }
        return saveUserRoleRelation(userId,roleIdList);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public List<UserRoleDTO> listUserRole(String userId, String roleId,String roleName) {
        return userRoleRelationService.listUserRole(userId,roleId,roleName);
    }

    @Override
    public List<UserRoleDTO> listUserRoleByUserIds(List<String> userIds) {
        if (CollUtil.isEmpty(userIds)){
            return CollUtil.newArrayList();
        }

        return userRoleRelationService.listUserRoleByUserIds(userIds);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void deleteUserRoleRelation(String userId) {
        userRoleRelationService.lambdaUpdate().eq(SystemUserRoleRelation::getUserId,userId).remove();
    }


}
